@@ -2,6 +2,7 @@ import re
 import logging
 from collections import OrderedDict
 from typing import Tuple
+import pandas as pd
 
 logger = logging.getLogger()
 
@@ -28,6 +29,33 @@ class FieldList(list):
         return ', '.join([ v for v in self ])
 
 class Utils:
+
+    @classmethod
+    def parse_describe_df(cls, df:pd.DataFrame) -> Tuple[FieldDefinition, FieldDefinition]:
+        df = df[['col_name','data_type']]
+        L = df.to_dict('record')
+
+        fields = FieldDefinition()
+        partitions = FieldDefinition()
+        is_fields = True
+        for row in L :
+            col = row['col_name']
+            dtype = row['data_type']
+            
+            if col == '# Partition Information':
+                is_fields = False
+                continue
+            if col == '# col_name':
+                continue
+            
+            if is_fields:
+                fields[col] = dtype
+            else:
+                del fields[col]
+                partitions[col] = dtype
+
+        return fields, partitions
+
     @classmethod
     def parse_schema(cls, schema: str) -> Tuple[FieldDefinition, FieldDefinition]:
 
